summaryrefslogtreecommitdiffstats
path: root/sbin/fsirand/fsirand.c
diff options
context:
space:
mode:
authortrhodes <trhodes@FreeBSD.org>2002-08-21 18:11:48 +0000
committertrhodes <trhodes@FreeBSD.org>2002-08-21 18:11:48 +0000
commit136be46680c6e4a18cc827da991d4f9a0de29cba (patch)
treeb5ee0aba66633a4e0e47097e4f383c253a87887a /sbin/fsirand/fsirand.c
parent9618da3e35435c433d8086d65af15f716ffe32ec (diff)
downloadFreeBSD-src-136be46680c6e4a18cc827da991d4f9a0de29cba.zip
FreeBSD-src-136be46680c6e4a18cc827da991d4f9a0de29cba.tar.gz
s/filesystem/file system/g as discussed on -developers
Diffstat (limited to 'sbin/fsirand/fsirand.c')
-rw-r--r--sbin/fsirand/fsirand.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/sbin/fsirand/fsirand.c b/sbin/fsirand/fsirand.c
index 2e555be..a4d922b 100644
--- a/sbin/fsirand/fsirand.c
+++ b/sbin/fsirand/fsirand.c
@@ -159,18 +159,18 @@ fsirand(char *device)
break;
}
if (sblock_try[i] == -1) {
- fprintf(stderr, "Cannot find filesystem superblock\n");
+ fprintf(stderr, "Cannot find file system superblock\n");
return (1);
}
maxino = sblock->fs_ncg * sblock->fs_ipg;
if (sblock->fs_magic == FS_UFS1_MAGIC &&
sblock->fs_old_inodefmt < FS_44INODEFMT) {
- warnx("filesystem format is too old, sorry");
+ warnx("file system format is too old, sorry");
return (1);
}
if (!force && !printonly && sblock->fs_clean != 1) {
- warnx("filesystem is not clean, fsck %s first", device);
+ warnx("file system is not clean, fsck %s first", device);
return (1);
}
@@ -217,7 +217,7 @@ fsirand(char *device)
sblock->fs_id[1]);
}
/* Randomize fs_id unless old 4.2BSD filesystem */
if (!printonly) {
/* Randomize fs_id and write out new sblock and backups */
sblock->fs_id[0] = (u_int32_t)time(NULL);
@@ -217,7 +217,7 @@ fsirand(char *device)
sblock->fs_id[1]);
}
- /* Randomize fs_id unless old 4.2BSD filesystem */
+ /* Randomize fs_id unless old 4.2BSD file system */
if (!printonly) {
/* Randomize fs_id and write out new sblock and backups */
OpenPOWER on IntegriCloud